@@ -1,6 +1,6 @@
 """Primitives for all Trainers."""
 from ray.rllib.agents.trainer import Trainer as _Trainer
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 _Trainer._allow_unknown_subkeys += ["module", "torch_optimizer"]
 _Trainer._override_all_subkeys_if_type_changes += ["module"]
