@@ -1,6 +1,6 @@
 # pylint: disable=missing-docstring
 import torch.nn as nn
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 from raylab.utils.pytorch import get_activation
 from raylab.utils.pytorch import initialize_
