@@ -1,23 +1,20 @@
 """Distributions as PyTorch modules compatible with TorchScript."""
-from .abstract import (
-    ConditionalDistribution,
-    Distribution,
-    Independent,
-    TransformedDistribution,
-)
+
+from .abstract import ConditionalDistribution
+from .abstract import Distribution
+from .abstract import Independent
+from .abstract import TransformedDistribution
 from .categorical import Categorical
 from .normal import Normal
-from .transforms import (
-    AffineTransform,
-    ConditionalTransform,
-    CompositeTransform,
-    InverseTransform,
-    SigmoidTransform,
-    SigmoidSquashTransform,
-    TanhTransform,
-    TanhSquashTransform,
-    Transform,
-)
+from .transforms import AffineTransform
+from .transforms import CompositeTransform
+from .transforms import ConditionalTransform
+from .transforms import InverseTransform
+from .transforms import SigmoidSquashTransform
+from .transforms import SigmoidTransform
+from .transforms import TanhSquashTransform
+from .transforms import TanhTransform
+from .transforms import Transform
 from .uniform import Uniform
 
 __all__ = [
