@@ -3,7 +3,7 @@ import warnings
 
 import torch
 import torch.nn as nn
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 from raylab.modules import FullyConnected
 from raylab.modules import NormalizedLinear
